Struct ResponseComment
pub struct ResponseComment {
pub author: Box<Profile>,
pub response: String,
pub content: String,
pub id: String,
pub timestamp: u128,
pub reply: Option<Box<ResponseComment>>,
pub edited: u128,
pub ip: String,
pub context: CommentContext,
}Expand description
A comment structure
Fields
The author of the comment; cannot be anonymous
response: StringID of the response this comment is replying to
content: StringThe content of the comment
id: StringThe ID of the comment
timestamp: u128The time this comment was created
reply: Option<Box<ResponseComment>>The ID of the comment this comment is replying to
edited: u128The time this comment was last edited
ip: StringThe IP address of the user creating the comment
context: CommentContextExtra information about the comment